MENU_ITEM_META_DELIM = "\r!"

FLAG_STYLE_URGENT = "URGENT"
FLAG_STYLE_ACTIVE = "ACTIVE"

OP_OUTPUT = "OUTPUT_MENU"
OP_REFRESH_MENU = "REFRESH_MENU"
OP_BACK_TO_PARENT_MENU = "BACK_TO_PARENT_MENU"
OP_EXIT = "EXIT"

ROOT_MENU_ID = "root"
